#!/usr/local/bin/perl
#
# take in an html file and an error file produced by tidy
# and output a new html file with the error information merged 
# into html as marked up comments
#

if ($#ARGV != 2) {
    print "usage: perl merge-tidy-files.pl <html imput filename> <text tidy error filename> <html output filename>\n";
    exit;
}

$inhtml = $ARGV[0];
$errors = $ARGV[1];
$output = $ARGV[2];

open(IN, $inhtml);
open(ERR, $errors);
open(OUT, ">$output");

$in_linenumber = 0;

$comment_begin = "<!-- ";
$comment_end = " -->";

while ($errline = <ERR>) 
{
    if (0 == index($errline, "line "))
    {
	chomp($errline);
	@parts = split(/ /, $errline); 
	$err_linenumber = $parts[1];

	if ($err_linenumber >= $in_linenumber)
	{
	    while ($err_linenumber > $in_linenumber)
	    {
		if ($inline = <IN>)
		{
		    $in_linenumber++;
		    print_in_line();
		}
		else
		{
		    last;
		}
	    }
	}

	print_error_line();
    }
    else
    {
	print_remaining_lines();
	last;
    }
}

close(IN);
close(ERR);
close(OUT);

sub print_in_line
{
    print OUT $comment_begin;
    print OUT $in_linenumber;
    print OUT $comment_end;
    print OUT $inline;
}

sub print_error_line
{
    print OUT $comment_begin . "TIDY ";
    print OUT $parts[5] . $parts[1] . substr($errline, index($errline, ":"), 500);
    print OUT " -- TIDY" . $comment_end . "\n";
}

sub print_remaining_lines
{
    while ($inline = <IN>)
    {
	$in_linenumber++;
        print_in_line();
    }

    print OUT $comment_begin;
    print OUT "TIDY COMMENTS\n";
    print OUT $errline;
    print $errline;

    while ($errline = <ERR>)
    {
        print OUT $errline;
        print $errline;
    }

    print OUT $comment_end;
}
